library(tinytest)
library(tiledb)

ctx <- tiledb_ctx(limitTileDBCores())
uri <- tempfile()
data <- data.frame(grp = rep(1:4, each=10), 				# 4 distinct groups
                   val = rep(1:4, each=10) * 100 + 1:10)    # and 4 sets of value (used as index)
times <- Sys.time() + 0:3          			# pre-allocate for time stamps
deltat <- 0.100                     		# start with this gap of 'delta_t'

if (dir.exists(uri)) unlink(uri, TRUE)

fromDataFrame(subset(data, grp==1), # write array, but only write group one
              uri, sparse=TRUE,
              col_index="val", tile_domain=list(val=range(data$val)))

arr <- tiledb_array(uri)
for (i in 2:4) {                        # in loop, write groups two to four
    Sys.sleep(deltat)
    arr[] <- subset(data, grp==i)
    times[i] <- Sys.time()              # and note time
}

## we need an 'epsilon' because when we record 'times' is not exactly where the array timestamp is
epst <- deltat/2

res2 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[1]-epst, timestamp_end=times[2]+epst)[]    # end after 2nd timestamp
